@@ -1,3 +1,4 @@
+import pytest
 from pathlib import Path
 from indico.client import IndicoClient
 from indico.queries import RetrieveStorageObject, JobStatus, WorkflowSubmission, ListWorkflowsForDataset
@@ -9,7 +10,6 @@ def test_list_workflows(indico, airlines_dataset, airlines_model_group: ModelGro
     wfs = client.call(ListWorkflowsForDataset(airlines_dataset.id))
     assert len(wfs) > 0    
 
-
 def test_workflow_submission(indico, airlines_dataset, airlines_model_group: ModelGroup):
     client = IndicoClient()
     wfs = client.call(ListWorkflowsForDataset(airlines_dataset.id))
@@ -20,14 +20,15 @@ def test_workflow_submission(indico, airlines_dataset, airlines_model_group: Mod
     job = client.call(WorkflowSubmission(workflow_id=wf.id, files=[dataset_filepath]))
 
     assert job.id != None
-    job = client.call(JobStatus(id=job.id, wait=False))
-    # TODO uncheck when submission is ready 
-    # assert job.status == "SUCCESS"
-    # assert job.ready == True
-    # assert type(job.result["url"]) == str
+    job = client.call(JobStatus(id=job.id, wait=True))
+    assert job.status == "SUCCESS"
+    assert job.ready == True
+    assert isinstance(job.result["url"], str)
+
+    result = client.call(RetrieveStorageObject(
+       job.result
+    ))
+
+    assert isinstance(result, str)
 
-    # result = client.call(RetrieveStorageObject(
-      #  job.result
-    #))
 
-    
\ No newline at end of file
